" Vim syntax file
" Language:     Inno Setup File (iss file) and My InnoSetup extension
"               http://www.innosetup.org/      http://www.wintax.nt/isx
" Maintainer:   Dominique Stphan (dominique@mggen.com)
" URL:          http://www.mggen.com/vim/
" Last Change:  2002 Dec 3


" For version 5.x: Clear all syntax items
" For version 6.x: Quit when a syntax file was already loaded
if version < 600
  syntax clear
elseif exists("b:current_syntax")
  finish
endif

" shut case off
syn case ignore

" Section
syn region issHeader            start="\[" end="\]"

" Label in the [Setup] Section
syn match  issLabel             "^\S[^=^:]\+="

" URL
syn match  issURL               "http[s]\=:\/\/.*$"

" syn match  issName            "[^: ]\+:"
syn match  issName              "Name:"
syn match  issName              "MinVersion:\|OnlyBelowVersion:"
syn match  issName              "Source:\|DestDir:\|DestName:\|CopyMode:"
syn match  issName              "Attribs:\|FontInstall:\|Flags:"
syn match  issName              "FileName:\|Parameters:\|WorkingDir:\|Comment:\|StatusMsg:"
syn match  issName              "IconFilename:\|IconIndex:"
syn match  issName              "Section:\|Key:\|String:"
syn match  issName              "Root:\|SubKey:\|ValueType:\|ValueName:\|ValueData:"
syn match  issName              "RunOnceId:"
syn match  issName              "Type:\|Tasks:"
syn match  issName              "Components:\|Description:\|GroupDescription\|Types:"
syn match  issName              "ExtraDiskSpaceRequired:\|HotKey:"
syn match  issName              "Check:"

syn match  issComment           "^;.*$" contains=issCommentTitle
syn match  issCommentTitleLeader '^;\s\+'ms=s+1  contained
syn match  issCommentTitle      '^;\s*\u\a*\(\s\+\u\a*\)*:'hs=s+1 contained contains=issCommentTitleLeader

" folder constant
syn match  issFolderSpecial     "ini:\|reg:\|param:\|code:"
syn match  issFolder            "{[^{]*}" contains=issFolderSpecial

" string
syn region issString            start=+"+  end=+"+ contains=issFolder

" [Setup]

" [Types]
syn keyword issTypesFlags iscustom

" [Components]
syn keyword issComponentsFlags fixed restart disablenouninstallwarning

" [Tasks]
syn keyword issTasksFlags checkedonce exclusive restart unchecked 

" [Dirs]
syn keyword issDirsFlags deleteafterinstall uninsalwaysuninstall uninsneveruninstall 

" [Files]
syn keyword issFilesCopyMode normal onlyifdoesntexist alwaysoverwrite alwaysskipifsameorolder 
syn keyword issFilesAttribs readonly hidden system
syn keyword issFilesFlags allowunsafefiles comparetimestampalso 
syn keyword issFilesFlags confirmoverwrite deleteafterinstall 
syn keyword issFilesFlags external fontisnttruetype isreadme
syn keyword issFilesFlags noregerror onlyifdestfileexists overwritereadonly 
syn keyword issFilesFlags recursesubdirs regserver regtypelib restartreplace
syn keyword issFilesFlags sharedfile skipifsourcedoesntexist uninsneveruninstall 

" [Icons]
syn keyword issIconsFlags closeonexit createonlyiffileexists dontcloseonexit
syn keyword issIconsFlags runmaximized runminimized uninsneveruninstall useapppaths 

" [INI]
syn keyword issINIFlags createkeyifdoesntexist uninsdeleteentry
syn keyword issINIFlags uninsdeletesection uninsdeletesectionifempty 

" [InstallDelete]

" [Message]

" [LangOptions]

" [Registry] 
syn keyword issRegRootKey   HKCR HKCU HKLM HKU HKCC
syn keyword issRegValueType none string expandsz multisz dword binary 
" Deal with pascal script type
" syn match   issRegName  "ValueType:[^;]*" contains=issName,issRegValueType
syn keyword issRegFlags createvalueifdoesntexist deletekey deletevalue
syn keyword issRegFlags dontcreatekey noerror preservestringtype 
syn keyword issRegFlags uninsclearvalue uninsdeletekey uninsdeletekeyifempty uninsdeletevalue 

" [Run] and [UninstallRun]
syn keyword issRunFlags hidewizard nowait shellexec skipifdoesntexist
syn keyword issRunFlags runmaximized runminimized waituntilidle postinstall
syn keyword issRunFlags unchecked skipifsilent skipifnotsilent showcheckbox

" [UninstallDelete] and [InstallDelete]
syn keyword issInstallDeleteType files filesandordirs dirifempty 

" [Code] section
" ISX InnerFuse Pascal
syn keyword issCodeKeyWord contained   program begin end
syn keyword issCodeKeyWord contained   case goto 
syn keyword issCodeKeyWord contained   if else then
syn keyword issCodeKeyWord contained   do for while to until

" syn keyword issCodeOperator   := + -

syn region  issCodeString  contained   start=+'+  end=+'+

syn keyword issCodeType    contained   char const integer real text
syn keyword issCodeType    contained   var type string boolean

syn keyword issCodeFunction contained  procedure function

syn keyword issCodeEvent   contained   InitializeSetup DeInitializeSetup CurStepChanged
syn keyword issCodeEvent   contained   NextButtonClick BackButtonClick SkipCurPage
syn keyword issCodeEvent   contained   CurPageChanged CheckPassword NeedRestart
syn keyword issCodeEvent   contained   UpdateReadyMemo RegisterPreviousData 

syn keyword issCodeConstant contained  csStart csWizard csCopy csFinished csTerminate 
syn keyword issCodeConstant contained  wpWelcome wpLicense wpPassword wpInfoBefore
syn keyword issCodeConstant contained  wpSelectDir wpSelectComponents wpSelectProgramGroup 
syn keyword issCodeConstant contained  wpSelectTasks wpReady
syn keyword issCodeConstant contained  wpInstalling wpInfoAfter wpFinished

syn region  issCodeComment   contained  start="(\*"  end="\*)"
syn region  issCodeComment   contained  start="{"  end="}"

" From [Code] section to next section or EOF
" syn region issCode start=+^\[Code\]+  end=+^\(\[\w*\]\)\|EOF+ contains=issCodeComment,issCodeConstant,issCodeEvent,issCodeFunction,issCodeType,issCodeString,issCodeKeyword,issHeader

" begin by "program", "function" or "procedure" and end with last "end." or "end;"
syn region issCode keepend start=+^\(function\|procedure\|program\|begin\)+ end=+^end\s*[;\.]+ contains=issCodeComment,issCodeConstant,issCodeEvent,issCodeFunction,issCodeType,issCodeString,issCodeKeyword

" Define the default highlighting.
" For version 5.7 and earlier: only when not done already
" For version 5.8 and later: only when an item doesn't have highlighting yet
if version >= 508 || !exists("did_iss_syntax_inits")
  if version < 508
    let did_iss_syntax_inits = 1
    command -nargs=+ HiLink hi link <args>
  else
    command -nargs=+ HiLink hi def link <args>
  endif

   " The default methods for highlighting.  Can be overridden later
   HiLink issHeader             Special
   HiLink issComment            Comment
   HiLink issLabel              Type
   HiLink issName               Type
   HiLink issFolderSpecial      String
   HiLink issFolder             Special
   HiLink issString             String
   HiLink issValue              String
   HiLink issURL                Include

   HiLink issDirsFlags          Keyword
   HiLink issFilesCopyMode      Keyword
   HiLink issFilesAttribs       Keyword
   HiLink issFilesFlags         Keyword
   HiLink issIconsFlags         Keyword
   HiLink issINIFlags           Keyword
   HiLink issRegRootKey         Keyword
   HiLink issRegValueType       Keyword
   HiLink issRegFlags           Keyword
   HiLink issRunFlags           Keyword
   HiLink issTypesFlags         Keyword
   HiLink issComponentsFlags    Keyword
   HiLink issTasksFlags         Keyword
   HiLink issInstallDeleteType  Keyword

   HiLink issCodeKeyWord        KeyWord
   HiLink issCodeString         String
   HiLink issCodeComment        Comment
   HiLink issCommentTitle       PreProc
   HiLink issCodeType           Type
   HiLink issCodeFunction       Include
   HiLink issCodeEvent          Special
   HiLink issCodeConstant       String  

  delcommand HiLink
endif

let b:current_syntax = "iss"

" vim:ts=8
